#!/bin/bash
#-----------------------------------------------------------------------------
# dnxClientTest.sh - tests the functionality of the DNX client
#
# Environment variables (optional):
#   DNX_CLIENT_DEBUG_LEVEL: specifies the debug level of the client (0)
#   DNX_NO_CLEANUP_AFTER_TESTS: doesn't remove the test output directory
#
#-----------------------------------------------------------------------------

# cleanup and create a testrun directory
rm -rf testrun
mkdir testrun

# check for environment variables
client_debug_level=$DNX_CLIENT_DEBUG_LEVEL
if [ -z "$client_debug_level" ]; then
   client_debug_level=0
fi

# ports used in config files
dispatcher_port=13480
collector_port=13481
client_agent_port=13482

# remote host
remote_host=$DNX_REMOTE_HOST
if [ -z "$remote_host" ]; then
   remote_host=localhost
fi

# bind address
bind_addr=$DNX_BIND_ADDRESS
if [ -z "$bind_addr" ]; then
   bind_addr=0
fi

# build client config file
cat << END_CLIENT_CONFIG_FILE > $PWD/testrun/test-client.cfg
channelDispatcher = udp://$remote_host:$dispatcher_port
channelCollector = udp://$remote_host:$collector_port
channelAgent = udp://$bind_addr:$client_agent_port
logFile = $PWD/testrun/test-client.log
debugFile = $PWD/testrun/test-client.dbg
debugLevel = $client_debug_level
runPath = $PWD/testrun
pluginPath = $PWD/testrun
# user
# group
# poolInitial
# poolMin
# poolMax
# poolGrow
# wlmPollInterval
# wlmShutdownGracePeriod
# threadRequestTimeout
# threadMaxRetries
# threadTtlBackoff
# maxResultBuffer
# showNodeAddr
END_CLIENT_CONFIG_FILE

# Execute the dnx client as a daemon
../dnxClient -c $PWD/testrun/test-client.cfg

# Give it time to create its lock file
count=0
while ((count<30)) && [ ! -e $PWD/testrun/dnxClient.pid ]; do
	sleep 1; let count++
done

# Ensure we HAVE a lock file now
if [ ! -e $PWD/testrun/dnxClient.pid ]; then
	echo "dnxClient.pid NOT found - daemon didn't start!"
	exit 1
fi

# Hit it with a dnxstats GETVERSION request
../../stats/dnxstats -p $client_agent_port -c GETVERSION
status=$?
if [ $status -ne 0 ]; then
	echo "dnxstats couldn't request client version!"
fi

# Send a SIGTERM - wait up to 15 seconds for it to die
# echo "dnxClient PID:" `cat $PWD/testrun/dnxClient.pid`
kill `cat $PWD/testrun/dnxClient.pid`

# Give it time to remove its lock file
count=0
while ((count<60)) && [ -e $PWD/testrun/dnxClient.pid ]; do
	sleep 1; let count++
done

# Ensure we DON'T have a lock file now
if [ -e $PWD/testrun/dnxClient.pid ]; then
	echo "dnxClient.pid still exists - daemon didn't stop!"
	exit 1
fi

# Remove all droppings
if [ -z "$DNX_NO_CLEANUP_AFTER_TESTS" ]; then
   rm -rf testrun
fi

exit $status

#-----------------------------------------------------------------------------

