/*--------------------------------------------------------------------------
 
   Copyright (c) 2006-2010, Intellectual Reserve, Inc. All rights reserved.
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License version 2 as 
   published by the Free Software Foundation.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
  --------------------------------------------------------------------------*/

/** Definitions and prototypes for main module functionality.
 *
 * This header file is shared by the Plugin and the Server in order to define
 * structures and definitions used in IPC communications between the two.
 *
 * @file dnx/plugin/dnxNebMain.h
 * @author John Calcote (dnx-devel@lists.sourceforge.net)
 * @attention Please submit patches to http://dnx.sourceforge.net
 * @ingroup DNX_PLUGIN_IFC
 */

#ifndef _DNXNEBMAIN_H_
#define _DNXNEBMAIN_H_

#include <stddef.h>
#include <time.h>

/* File descriptors used on server side of pipe. */
#define DNX_SRVFD                4  //!< job    -> server : file descriptor
#define DNX_SAKFD                5  //!< plugin <- joback : file descriptor
#define DNX_PLGFD                6  //!< plugin <- results: file descriptor
#define DNX_PAKFD                7  //!< resack -> server : file descriptor

/* Various field values for sanity checking */
#define DNX_MAX_XFER_SIZE        (64 * 1024) //!< maximum job size
#define DNX_MSG_SIGNATURE        0xFEED5000  //!< message header signature

/* Transfer message types */
#define DNX_MSG_RESERVE_NODEREQ  0  //!< Reserve a node request.
#define DNX_MSG_JOB_TRANSFER     1  //!< Transfer a job.
#define DNX_MSG_RESULT_TRANSFER  2  //!< Transfer a result.
#define DNX_MSG_TERMINATE        3  //!< Terminate the child process.

/** The message header found at the top of all transfer messages. */
typedef struct DnxMsgHeader
{
   size_t structsz;                 //!< The size in bytes of this messsage.
   unsigned signature;              //!< A message signature value.
   int msgtype;                     //!< The type of this message.
} DnxMsgHeader;

/** The job data structure passed from plugin to server. */
typedef struct DnxJobTransfer
{
   DnxMsgHeader hdr;                //!< The message transfer header.
   unsigned long serial;            //!< The serial number of this job.
   void * payload;                  //!< An opaque value used by the result poster.
   void * svc;                      //!< An opaque pointer to the nagios service check.
   time_t start_time;               //!< The service check start time.
   int timeout;                     //!< The service check timeout in seconds.
   time_t expires;                  //!< The service check expiration time.
   int chkopts;                     //!< The nagios 3.x check options.
   int schedule;                    //!< The nagios 3.x schedule flag.
   int reschedule;                  //!< The nagios 3.x reschedule flag.
   char cmd[1];                     //!< A variable length command buffer.
} DnxJobTransfer;

/** The result data structure passed from server to plugin. */
typedef struct DnxResultTransfer
{
   DnxMsgHeader hdr;                //!< The message transfer header.
   unsigned long serial;            //!< The serial number of the associated job.
   void * payload;                  //!< An opaque value used by the result poster.
   time_t start_time;               //!< The start time of the job.
   unsigned delta;                  //!< The delta between start and end time.
   int early_timeout;               //!< A boolean flag indicating early timeout.
   int res_code;                    //!< The result code of the check.
   char res_data[1];                //!< A variable length result data buffer.
} DnxResultTransfer;

#endif   /* _DNXNEBMAIN_H_ */

