#!/bin/sh
#-----------------------------------------------------------------------------
# dnxPluginTest.sh - tests the functionality of the Nagios DNX plugin
#
# Environment variables (optional):
#   DNX_CLIENT_DEBUG_LEVEL: specifies the debug level of the client (0)
#   DNX_PLUGIN_DEBUG_LEVEL: specifies the debug level of the plugin (0)
#   DNX_SERVER_DEGUG_LEVEL: specifies the debug level of the server (0)
#   DNX_BIND_ADDR: specifies the bind address to use for listening (0)
#   DNX_REMOTE_HOST: specifies the remote host to use (localhost)
#   DNX_KEYSTROKE_TERMINATE: keep server & client till keypress (in mockNagios)
#   DNX_NO_CLEANUP_AFTER_TESTS: doesn't remove the test output directory
#
#-----------------------------------------------------------------------------

# configure variables
testdir=testrun
check_script=check.script
plugin=$1
if [ -z "$plugin" ]; then
   plugin=../.libs/dnxPlugin.so
fi

client_debug_level=$DNX_CLIENT_DEBUG_LEVEL
if [ -z "$client_debug_level" ]; then
   client_debug_level=0
fi

server_debug_level=$DNX_SERVER_DEBUG_LEVEL
if [ -z "$server_debug_level" ]; then
   server_debug_level=0
fi

plugin_debug_level=$DNX_PLUGIN_DEBUG_LEVEL
if [ -z "$plugin_debug_level" ]; then
   plugin_debug_level=0
fi

# ports used in config files
dispatcher_port=13480
collector_port=13481
client_agent_port=13482
server_agent_port=13483

# remote host
remote_host=$DNX_REMOTE_HOST
if [ -z "$remote_host" ]; then
   remote_host=localhost
fi

# bind address
bind_addr=$DNX_BIND_ADDRESS
if [ -z "$bind_addr" ]; then
   bind_addr=0
fi

# cleanup and create a test directory
rm -rf $testdir
mkdir $testdir

# build client config file
cat << END_CLIENT_CONFIG_FILE > $PWD/$testdir/test-client.cfg
channelDispatcher = udp://$remote_host:$dispatcher_port
channelCollector = udp://$remote_host:$collector_port
channelAgent = udp://$bind_addr:$client_agent_port
logFile = $PWD/$testdir/test-client.log
debugFile = $PWD/$testdir/test-client.dbg
debugLevel = $client_debug_level
runPath = $PWD/$testdir
pluginPath = $PWD/$testdir
# user
# group
# poolInitial
# poolMin
# poolMax
# poolGrow
# wlmPollInterval
# wlmShutdownGracePeriod
# threadRequestTimeout
# threadMaxRetries
# threadTtlBackoff
# maxResultBuffer
# showNodeAddr
END_CLIENT_CONFIG_FILE

# build server config file
cat << END_SERVER_CONFIG_FILE > $PWD/$testdir/test-server.cfg
channelDispatcher = udp://$bind_addr:$dispatcher_port
channelCollector = udp://$bind_addr:$collector_port
channelAgent = udp://$bind_addr:$server_agent_port
serverPath = ../server/dnxServer
logFile = $PWD/$testdir/test-server.log
debugFile = $PWD/$testdir/test-server.dbg
debugLevel = $server_debug_level
auditFile = $PWD/$testdir/test-server.aud
pluginLogFile = $PWD/$testdir/test-plugin.log
pluginDebugFile = $PWD/$testdir/test-plugin.dbg
pluginDebugLevel = $plugin_debug_level
pluginAuditFile = $PWD/$testdir/test-plugin.aud
runPath = $PWD/$testdir
# localCheckPattern
# syncScript
# authWorkerNodes
# maxNodeRequests
# minServiceSlots
# expirePollInterval
END_SERVER_CONFIG_FILE

# Create required "test" script in test directory
echo "#!/bin/sh
/bin/sh \$*" > $PWD/$testdir/check.script
chmod 755 $PWD/$testdir/check.script

# Execute the dnx client as a daemon
../../client/dnxClient -c $PWD/$testdir/test-client.cfg

# Give it time to create its lock file
count=0
while ((count<30)) && [ ! -e $PWD/$testdir/dnxClient.pid ]; do
	sleep 1; let count++
done

# Ensure we HAVE a lock file now
if [ ! -e $PWD/$testdir/dnxClient.pid ]; then
	echo "dnxClient.pid NOT found - daemon didn't start!"
	exit 1
fi

# run mockNagios server with dnxPlugin against dnxClient
./mockNagios $testdir $plugin $testdir/test-server.cfg
status=$?

# Send a SIGTERM - wait up to 15 seconds for it to die
# echo "dnxClient PID:" `cat $PWD/$testdir/dnxClient.pid`
kill `cat $PWD/$testdir/dnxClient.pid`

# Give it time to remove its lock file
count=0
while ((count<60)) && [ -e $PWD/$testdir/dnxClient.pid ]; do
	sleep 1; let count++
done

# Ensure we DON'T have a lock file now
if [ -e $PWD/$testdir/dnxClient.pid ]; then
	echo "dnxClient.pid still exists - daemon didn't stop!"
	exit 1
fi

# Remove all droppings
if [ -z "$DNX_NO_CLEANUP_AFTER_TESTS" ]; then
   rm -rf $testdir
fi

# return exit code from mockNagios run
exit $status

#-----------------------------------------------------------------------------

